@@ -161,6 +161,34 @@ impl Base {
         (1.0 - ((1.0 - c_score) * (1.0 - i_score) * (1.0 - a_score)).abs()).into()
     }
 
+    /// Iterate over all defined Base metrics
+    pub fn metrics(&self) -> impl Iterator<Item = (MetricType, &dyn fmt::Debug)> {
+        [
+            (
+                MetricType::AV,
+                self.av.as_ref().map(|m| m as &dyn fmt::Debug),
+            ),
+            (
+                MetricType::AC,
+                self.ac.as_ref().map(|m| m as &dyn fmt::Debug),
+            ),
+            (
+                MetricType::PR,
+                self.pr.as_ref().map(|m| m as &dyn fmt::Debug),
+            ),
+            (
+                MetricType::UI,
+                self.ui.as_ref().map(|m| m as &dyn fmt::Debug),
+            ),
+            (MetricType::S, self.s.as_ref().map(|m| m as &dyn fmt::Debug)),
+            (MetricType::C, self.c.as_ref().map(|m| m as &dyn fmt::Debug)),
+            (MetricType::I, self.i.as_ref().map(|m| m as &dyn fmt::Debug)),
+            (MetricType::A, self.a.as_ref().map(|m| m as &dyn fmt::Debug)),
+        ]
+        .into_iter()
+        .filter_map(|(name, metric)| metric.as_ref().map(|&m| (name, m)))
+    }
+
     /// Calculate Base CVSS `Severity` according to the
     /// Qualitative Severity Rating Scale (i.e. Low / Medium / High / Critical)
     ///
